<?php
/**
* Reef About Widget
*
* @since Reef 0.1
*/
if( ! class_exists( 'Reef_About_Widget' ) ) :
    
    class Reef_About_Widget extends Reef_Base_Widget {

        public function __construct() {
            parent::__construct(
                'reef_about_widget', 
                esc_html__( 'Reef About Sidebar', 'reef' ),
                array( 'description' => esc_html__( 'Widget for your profile.', 'reef' ) ) 
            );

            $this->fields = array(
                'title' => array(
                    'label'   => esc_html__( 'Title', 'reef' ),
                    'type'    => 'text',
                ),
                'page_id' => array(
                    'label' => esc_html__( 'Select Page', 'reef' ),
                    'type'  => 'dropdown-pages',
                ),
                'sub_title' => array(
                    'label'   => esc_html__( 'Sub Title', 'reef' ),
                    'type'    => 'text',
                    'default' => esc_html__( 'Blogger','reef' )
                ),
            );
        }

        public function widget( $args, $instance ) {
            
            echo $args[ 'before_widget' ];

            $instance = $this->init_defaults( $instance );
            $unique_id = uniqid();
            ?>
            <?php if( $instance[ 'page_id' ] ): ?>

            <section class="<?php echo esc_attr( empty( $instance[ 'title' ] ) ? 'no-title': '' ); ?> wrapper sidebar-item sb-about-widget class-<?php echo esc_attr( $unique_id ); ?>">
                <?php
                echo '<div class="widget-title-wrap">' . $args[ 'before_title'] . esc_html( $instance[ 'title' ] ) . $args[ 'after_title' ] . '</div>';

                $query = new WP_Query( array(
                            'p'         => $instance[ 'page_id' ],
                            'post_type' => 'page'
                        ) );

                while( $query->have_posts() ){
                    $query->the_post();
                    if( has_post_thumbnail() ){

                      $src_lg = esc_url( get_the_post_thumbnail_url( $instance[ 'page_id' ], 'reef-about-widget-lg' ) );
                      $src_sm = esc_url( get_the_post_thumbnail_url( $instance[ 'page_id' ], 'reef-about-widget-sm' ) );
                    }else{

                      $src_lg = reef_get_dummy_image( array( 'size' => 'reef-about-widget-lg' ) );
                      $src_sm = reef_get_dummy_image( array( 'size' => 'reef-about-widget-sm' ) );
                    }
                ?>

                <style>
                    .sb-about-widget.class-<?php echo esc_attr( $unique_id ); ?> .widget-content .description:before{
                        background-image: url( '<?php echo $src_lg; ?>' );
                    }
                </style>
                <div class="widget-content">
                    <div class="description">
                        <div class="banner-overlay">
                           <div class="description-content">
                                <?php reef_excerpt( 22 ); ?>
                            </div>
                        </div>
                    </div>
                    <div class="profile">
                        <div class="avatar">
                            <figure>
                                 <a href="<?php the_permalink(); ?>">
                                      <img src="<?php echo esc_url( $src_sm ); ?>" >
                                 </a>
                            </figure>
                        </div>
                        <div class="name-title">
                            <headgroup>
                                <?php the_title( '<h2><a href="'. esc_url( get_permalink() ) .'">', '</a></h2>,' ); ?>
                                 <h3><?php echo esc_html( $instance[ 'sub_title' ] ); ?></h3>
                                 <?php reef_edit_link(); ?>
                            </headgroup>
                        </div>
                        <div class="button-container">
                            <a href="<?php the_permalink(); ?>" class="button-outline" >
                                <?php echo esc_html( apply_filters( 'reef_sb_about_btn_txt', __( 'Know More', 'reef' ) ) ); ?>
                            </a>
                        </div>
                    </div>
                </div>
                <?php } ?>
            </section>
            <?php endif; ?>
            <?php
            
            wp_reset_postdata();
            echo $args[ 'after_widget' ];
        }
    }

endif;